@@ -9,6 +9,26 @@ __all__ = [
 
 T = TypeVar('T')
 
+
+def deg(p):
+    d = len(p) - 1
+    while getattr(p[d], "id", p[d]) == 0 and d:
+        d -= 1
+    return d
+
+
+def poly_rounded_div(a, b, field=int):
+    dega = deg(a)
+    degb = deg(b)
+    temp = [field(x) for x in a]
+    o = [field(0) for x in a]
+    for i in range(dega - degb, -1, -1):
+        o[i] += temp[degb + i] / b[degb]
+        for c in range(degb + 1):
+            temp[c + i] -= o[c]
+    return o[:deg(o)+1]
+
+
 def bits(n: int) -> Iterable:
     """
     Generates the binary digits of n, starting
@@ -20,17 +40,19 @@ def bits(n: int) -> Iterable:
             yield n & 1
             n >>= 1
 
-    return list(_trans(n))
+    return _trans(n)
 
 
 def bits_little_endian_from_bytes(s):
-    return "".join([bin(ord(x))[2:].rjust(8,'0')[::-1] for x in s.decode()])
+    return "".join([bin(ord(x))[2:].rjust(8, '0')[::-1] for x in s.decode()])
+
 
 def bytes_from_bits_little_endian(s):
     return bytes([int(s[i:i+8][::-1], 2) for i in range(0, len(s), 8)])
 
+
 def bytes_mul(a, b, s=32):
-    t = [0] * 2* s
+    t = [0] * 2 * s
     a = a.to_bytes(s, "big")[::-1]
     b = b.to_bytes(s, "big")[::-1]
 
@@ -46,7 +68,8 @@ def bytes_mul(a, b, s=32):
 @lru_cache(maxsize=None)
 def montgomery_property(r, n):
     r_inv = invmod(r, n)
-    return (r * r_inv -1) // n
+    return (r * r_inv - 1) // n
+
 
 def mon_pro(a_, b_, r, n, n_):
     t = a_ * b_
@@ -57,8 +80,9 @@ def mon_pro(a_, b_, r, n, n_):
     else:
         return u_
 
+
 def montgomery_mul(a, b, n):
-    r = 2 ** (n.bit_length() +1)
+    r = 2 ** (n.bit_length() + 1)
     n_ = montgomery_property(r, n)
     a_ = (a * r) % n
     b_ = (b * r) % n
@@ -66,7 +90,6 @@ def montgomery_mul(a, b, n):
     return mon_pro(u_, 1, r, n, n_)
 
 
-
 def CIOS(a, b, P, N=32):
     """
     # a[i], b[i], q[i] is the ith word of the numbers a,b,q
@@ -110,7 +133,6 @@ def CIOS(a, b, P, N=32):
     return int.from_bytes(t, "little")
 
 
-
 def complex_truediv_algorithm(x: complex, y: complex, f: T) -> T:
     a = f(x.real)
     b = f(x.imag)
@@ -123,7 +145,7 @@ def complex_truediv_algorithm(x: complex, y: complex, f: T) -> T:
     ))
 
 
-def extended_euclidean_algorithm(a: int, b: int) -> Tuple[int, int, int]:
+def extended_euclidean_algorithm(a: int, b: int, one=1, zero=0) -> Tuple[int, int, int]:
     '''
     Returns a three-tuple (gcd, x, y) such that
     a * x + b * y == gcd, where gcd.
@@ -131,10 +153,10 @@ def extended_euclidean_algorithm(a: int, b: int) -> Tuple[int, int, int]:
     This function implements the extended Euclidean
     algotithm and runs in O(log b) in the worst case
     '''
-    s, t, r = 0, 1, b
-    old_s, old_t, old_r = 1, 0, a
+    s, t, r = zero, one, b
+    old_s, old_t, old_r = one, 0, a
 
-    while r != 0:
+    while r != zero:
         quoient = old_r // r
         old_r, r = r, old_r - quoient * r
         old_s, s = s, old_s - quoient * s
@@ -159,8 +181,20 @@ def double_and_add_algorithm(times: int, x: T, init: T) -> T:
     return result
 
 
+def fast_pow(times: int, x: T, init: T) -> T:
+    result = init
+    addend = x
+
+    for bit in bits(times):
+        if bit == 1:
+            result = addend * result
+        addend = addend * addend
+    return result
+
+
 def newton_iterator_sqrt(x: T):
-    if (x.value == 0): return x
+    if (x.value == 0):
+        return x
     last = x.__class__(0)
     res = x.__class__(1)
     while res != last:
