@@ -3,7 +3,7 @@ from klefki.utils import dhash256, ripemd160, b58encode
 from klefki.crypto.ecdsa.secp256k1 import (
     pubkey
 )
-from klefki.types.algebra.concrete import (
+from klefki.algebra.concrete import (
     EllipticCurveGroupSecp256k1 as ECG,
     FiniteFieldSecp256k1 as F
 )
@@ -38,5 +38,6 @@ def gen_address(pub: ECG) -> str:
     assert len(res) == 25
     return b58encode(res)
 
+
 def gen_address_from_priv(key) -> str:
     return gen_address(pubkey(key))
