@@ -5,11 +5,11 @@ from klefki.utils import b58encode, int_to_byte
 from klefki.crypto.ecdsa.secp256k1 import (
     random_privkey,
 )
-from klefki.types.algebra.concrete import (
+from klefki.algebra.concrete import (
     FiniteFieldCyclicSecp256k1 as CF,
 )
 
-from klefki.types.algebra.isomorphism import bijection, do
+from klefki.algebra.isomorphism import bijection, do
 
 
 def wrap_key(key: bytes, version=128, compress=1):
@@ -24,9 +24,11 @@ def wrap_key(key: bytes, version=128, compress=1):
 def unwrap_key(key: bytes):
     return key[1: -5]
 
+
 def to_cf(a: int):
     return CF(a)
 
+
 @bijection(to_cf)
 def from_cf(a: CF) -> int:
     return a.value
