@@ -6,8 +6,8 @@ from klefki.asn import signature as sig_asn
 from klefki.blockchain.bitcoin.private import decode_privkey
 from klefki.blockchain.bitcoin.public import decode_pubkey
 from klefki.utils import int_to_byte, byte_to_int, b64encode, b58encode
-from klefki.types.algebra.concrete import FiniteFieldCyclicSecp256k1 as CF
-from klefki.types.algebra.isomorphism import bijection, do
+from klefki.algebra.concrete import FiniteFieldCyclicSecp256k1 as CF
+from klefki.algebra.isomorphism import bijection, do
 
 
 @bijection(edr_encode)
