@@ -1,17 +1,18 @@
 from klefki.utils import int_to_byte
 from klefki.crypto.ecdsa.secp256k1 import pubkey
-from klefki.types.algebra.concrete import (
+from klefki.algebra.concrete import (
     EllipticCurveGroupSecp256k1 as ECG,
     FiniteFieldCyclicSecp256k1 as CF
 
 )
-from klefki.types.algebra.isomorphism import bijection, do
+from klefki.algebra.isomorphism import bijection, do
 from klefki.utils import ripemd160, b58encode, byte_to_int
 
 
 def to_bytes(pub: ECG) -> str:
     return bytes([2 + (pub.value[1].value % 2)]) + int_to_byte(pub.value[0].value)
 
+
 @bijection(to_bytes)
 def from_bytes(a):
     return ECG([
@@ -24,6 +25,7 @@ def checksum(a) -> int:
     assert len(a) == 33
     return 'EOS' + b58encode(a + ripemd160(a)[:4])
 
+
 @bijection(checksum)
 def unchecksum(a):
     return b58encode.inverse(a[3:])
