@@ -1,10 +1,10 @@
 from klefki.crypto.ecdsa.secp256k1 import pubkey
-from klefki.types.algebra.concrete import (
+from klefki.algebra.concrete import (
     EllipticCurveGroupSecp256k1 as ECG,
     FiniteFieldCyclicSecp256k1 as CF,
     FiniteFieldSecp256k1 as F
 )
-from klefki.types.algebra.isomorphism import bijection
+from klefki.algebra.isomorphism import bijection
 
 
 def encode_pubkey(key: ECG):
