@@ -1,8 +1,8 @@
 from klefki.curves.secp256k1 import EllipticCurveGroupSecp256k1 as Curve
-from klefki.types.algebra.concrete import FiniteFieldCyclicSecp256k1 as F
-from klefki.types.algebra.utils import randfield
-from klefki.types.algebra.meta import field
-from klefki.types.algebra.isomorphism import bijection
+from klefki.algebra.concrete import FiniteFieldCyclicSecp256k1 as F
+from klefki.algebra.utils import randfield
+from klefki.algebra.meta import field
+from klefki.algebra.isomorphism import bijection
 from klefki.utils import int_to_byte, byte_to_int
 
 
@@ -16,19 +16,18 @@ def map_to_curve(m, G=Curve.G, bias=1):
     except AssertionError:
         return map_to_curve(m, G=G, bias=bias+1)
 
+
 @bijection(map_to_curve)
 def map_from_curve(M):
     return int(str(M.x.value)[1:])
 
 
-
 class ElGamal():
 
     def __init__(self, x, g=Curve.G):
         self.privkey = x
         self.pubkey = g, g ** x
 
-
     @classmethod
     def encrypt(cls, m, pub):
         g, h = pub
@@ -39,7 +38,6 @@ class ElGamal():
         c2 = s * m_
         return (c1, c2)
 
-
     @classmethod
     def decrypt(cls, x, c):
         c1, c2 = c
@@ -47,10 +45,8 @@ class ElGamal():
         m = (c2 - s)
         return map_from_curve(m)
 
-
     def E(self, m):
         return self.encrypt(m, self.pubkey)
 
-
     def D(self, c):
         return self.decrypt(self.privkey, c)
