@@ -1,8 +1,8 @@
 from math import gcd
 from abc import ABCMeta
 from random import randint
-from klefki.types.algebra.utils import randfield
-from klefki.types.algebra.meta import field
+from klefki.algebra.utils import randfield
+from klefki.algebra.meta import field
 from klefki.numbers import lcm
 from functools import partial
 import random
@@ -30,7 +30,6 @@ class Paillier():
         self.privkey = Lam
         self.pubkey = (self.N, self.G)
 
-
     @classmethod
     def encrypt(cls, m, pub):
         N, G = pub
@@ -41,7 +40,6 @@ class Paillier():
         r = G.functor(random.randint(0, N))
         return G**m * r**N
 
-
     @classmethod
     def decrypt(cls, c, priv, pub):
         Lam = priv
@@ -53,11 +51,9 @@ class Paillier():
     def E(self, m, pub=None):
         return self.encrypt(m, pub or self.pubkey)
 
-
     def D(self, c, priv=None, pub=None):
         return self.decrypt(c, priv or self.privkey, pub or self.pubkey)
 
-
     def test(self):
         m = random.randint(0, self.N)
         assert m == self.D(self.E(m)).value
