@@ -1,7 +1,7 @@
 from klefki.crypto.ssss import SSSS
-from klefki.types.algebra.groups import EllipticCurveGroup
-from klefki.types.algebra.fields import FiniteField
-from klefki.types.algebra.utils import randfield
+from klefki.algebra.groups import EllipticCurveGroup
+from klefki.algebra.fields import FiniteField
+from klefki.algebra.utils import randfield
 from functools import reduce
 from operator import mul
 
@@ -11,8 +11,7 @@ class VSS(SSSS):
         self.G = G
         super().__init__(F, secret, k, n, poly_params)
 
-
-    def setup(self, secret, k, n, poly_params = []):
+    def setup(self, secret, k, n, poly_params=[]):
         if not poly_params:
             poly_params = [randfield(self.F) for _ in range(k - 1)]
 
@@ -20,11 +19,9 @@ class VSS(SSSS):
 
         return super().setup(secret, k, n, poly_params)
 
-
     def verify(self, x, y):
         return self.verify_proofs(x, y, self.poly_proofs, self.G, self.k)
 
-
     @staticmethod
     def verify_proofs(x, y, proofs, G, k):
         return G ** y == reduce(mul, [proofs[i] ** (x ** i) for i in range(k)])
