@@ -2,13 +2,12 @@
 DOC: https://eips.ethereum.org/EIPS/eip-2494
 """
 import klefki.const as const
-from klefki.types.algebra.fields import FiniteField
-from klefki.types.algebra.groups import EllipticCurveGroup
-from klefki.types.algebra.groups import EllipicCyclicSubgroup
+from klefki.algebra.fields import FiniteField
+from klefki.algebra.groups import EllipticCurveGroup
+from klefki.algebra.groups import EllipicCyclicSubgroup
 from klefki.curves.arith import short_weierstrass_form_curve_addition2
 
 
-
 class FiniteFieldBabyJubjub(FiniteField):
     P = const.BABYJUBJUB_P
 
@@ -24,7 +23,6 @@ class EllipticCurveBabyJubjub(EllipticCurveGroup):
     B = const.BABYJUBJUB_B
     N = const.BABYJUBJUB_N
 
-
     def op(self, g):
         # x3 = (x1*y2 + y1*x2)/(1 + b*x1*x2*y1*y2)
         # y3 = (y1*y2 - a*x1*x2)/(1 - b*x1*x2*y1*y2)
@@ -41,7 +39,8 @@ class EllipticCurveBabyJubjub(EllipticCurveGroup):
         y3 = (self.y * g.y - field(self.A) * self.x * g.x) / (field(1) - m)
         return self.__class__((x3, y3))
 
+
 EllipticCurveBabyJubjub.G = EllipticCurveBabyJubjub((
-        FiniteFieldBabyJubjub(const.BABYJUBJUB_Gx),
-        FiniteFieldBabyJubjub(const.BABYJUBJUB_Gy)
+    FiniteFieldBabyJubjub(const.BABYJUBJUB_Gx),
+    FiniteFieldBabyJubjub(const.BABYJUBJUB_Gy)
 ))
