@@ -1,7 +1,7 @@
 import klefki.const as const
-from klefki.types.algebra.fields import FiniteField
-from klefki.types.algebra.groups import EllipticCurveGroup
-from klefki.types.algebra.groups import EllipicCyclicSubgroup
+from klefki.algebra.fields import FiniteField
+from klefki.algebra.groups import EllipticCurveGroup
+from klefki.algebra.groups import EllipicCyclicSubgroup
 from klefki.curves.arith import short_weierstrass_form_curve_addition2
 
 
@@ -24,24 +24,24 @@ class EllipticCurveGroupSecp256k1(EllipticCurveGroup):
 
     @property
     def x(self):
-        if self == self.identity:
+        if self == self.zero():
             return 0
         return self.value[0]
 
     @property
     def y(self):
-        if self == self.identity:
+        if self == self.zero():
             return 0
         return self.value[1]
 
     def op(self, g):
-        field = self.value[0].__class__
+        field = self.id[0].__class__
         x, y = short_weierstrass_form_curve_addition2(
             self.x, self.y,
             g.x, g.y,
-            field(0),
-            field(0),
-            field(0),
+            field.zero(),
+            field.zero(),
+            field.zero(),
             field(self.A),
             field(self.B),
             field
@@ -50,6 +50,7 @@ class EllipticCurveGroupSecp256k1(EllipticCurveGroup):
             return self.__class__(0)
         return self.__class__((x, y))
 
+
 EllipticCurveGroupSecp256k1.G = EllipticCurveGroupSecp256k1(
     (
         FiniteFieldSecp256k1(const.SECP256K1_Gx),
