@@ -1,7 +1,7 @@
 import base58
 import base64
 from typing import Iterable, Iterator, Callable
-from klefki.types.algebra.isomorphism import bijection
+from klefki.algebra.isomorphism import bijection
 from klefki.curves.secp256k1 import (
     FiniteFieldCyclicSecp256k1 as CF,
 )
@@ -17,9 +17,11 @@ b64encode = bijection(base64.b64decode)(base64.b64encode)
 def int_to_byte(key: int, length=32) -> bytes:
     return key.to_bytes(length, byteorder='big')
 
+
 def int_to_byte64(key: int) -> bytes:
     return int_to_byte(key, 64)
 
+
 @bijection(int_to_byte)
 def byte_to_int(byte: bytes) -> CF:
     return int.from_bytes(byte, "big")
@@ -105,13 +107,13 @@ def CF2Bytes(cf, l=32):
 
 def to_u32s(a: int, endian="little"):
     l = math.ceil(a.bit_length() / 8)
+
     def split():
         carry = a
         while carry != 0:
             yield carry % 2**32
             carry = carry // (2 ** 32)
 
-
     return {
         "big": list(split())[::-1],
         "little": list(split())
