@@ -1,7 +1,7 @@
-from klefki.types.algebra.utils import randfield
+from klefki.algebra.utils import randfield
 from klefki.zkp.sigma import NIZK
-from klefki.types.algebra.concrete import FiniteFieldCyclicSecp256k1 as CF
-from klefki.types.algebra.concrete import EllipticCurveGroupSecp256k1 as Curve
+from klefki.algebra.concrete import FiniteFieldCyclicSecp256k1 as CF
+from klefki.algebra.concrete import EllipticCurveGroupSecp256k1 as Curve
 from hashlib import sha256
 
 class NIZKSchnoor(NIZK):
